@@ -3,8 +3,8 @@ use Perlmazing;
 sub main {
 	my ($type, $val) = @_;
 	if (is_blessed $val) {
-		$val->isa($type);
+		define $val->isa($type);
 	} else {
-		_is_ref $type, $val;
+		define _is_ref $type, $val;
 	}
 }
